@@ -1,12 +1,20 @@
 #!/usr/bin/python -O
 import ots
-import sys
+import sys, os
 import urllib
 import stripogram
 from optparse import OptionParser
-import chardet
-
+import webbrowser
+import tempfile
 
+try:
+    import chardet
+except ImportError:
+    class chardet:
+        @staticmethod
+        def detect(data):
+            return {'encoding' : sys.getdefaultencoding()}
+        
 
 if __name__ == "__main__":
     parser = OptionParser()
@@ -21,6 +29,15 @@ if __name__ == "__main__":
                       action="store_true",
                       help="Specify the two letter language code")
 
+    parser.add_option('-p', '--percentage',
+                      dest="percentage",
+                      default=20,
+                      type="int",
+                      help="percentage of doc to retain"
+                      )
+                      
+
+
     (options, args) = parser.parse_args()
 
     url = args[0]
@@ -36,10 +53,14 @@ if __name__ == "__main__":
     data = data.decode(enc).encode('utf-8')
 
     o = ots.OTS(options.language)
+    o.percentage = options.percentage
     o.parseUnicode(data)
     
     if options.html:
-        print o.asHTML()
+        fd, fn = tempfile.mkstemp(".html")
+        os.write(fd, o.asHTML())
+        os.close(fd)
+        webbrowser.open("file://%s" %fn)
     else:
         print "Title:", o.title
         print "Lines:", o.lineCount
